package com.taiji.system.config;

import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import springfox.documentation.builders.ApiInfoBuilder;
import springfox.documentation.builders.RequestHandlerSelectors;
import springfox.documentation.service.ApiInfo;
import springfox.documentation.spi.DocumentationType;
import springfox.documentation.spring.web.plugins.Docket;

/***
 * <p>
 * swagger 3.0 配置类
 * </p>
 * @author hou yi
 * @date 2023/1/29 14:12
 **/
@Configuration
public class SwaggerConfig {

    @Value("${swagger.enabled:false}")
    private Boolean enabled;

    @Bean
    public Docket createRestApi() {
        // v3 与 v2 不同
        return new Docket(DocumentationType.OAS_30)
                // 是否开启 swagger
                .enable(enabled)
                // api 信息
                .apiInfo(apiInfo())
                .select()
                // 设置扫描路径
                .apis(RequestHandlerSelectors.basePackage("com.taiji.system.controller"))
                .build()
                ;
    }

    private ApiInfo apiInfo() {
        return new ApiInfoBuilder()
                // 文档标题
                .title("文件管理系统接口文档")
                // 文档描述
                .description("文件管理系统接口说明")
                // 版本号
                .version("1,0.0")
                .build();
    }
}
