package com.taiji.system.controller;

import com.taiji.system.oss.FileUrlVo;
import com.taiji.system.oss.MinIoTemplate;
import com.taiji.system.oss.OssFile;
import com.taiji.system.util.ResultWrapper;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletResponse;

/***
 * <p>
 * 文件管理控制器
 * </p>
 * @author hou yi
 * @date 2022/11/21 9:47
 **/
@RestController
@RequestMapping("minIo")
@Api(tags = "MinIo 文件管理")
public class MinIoController {

    @Resource
    private MinIoTemplate minIoTemplate;

    @PostMapping("upload")
    @ApiOperation("上传文件")
    public ResultWrapper<OssFile> upload(@ApiParam("上传的文件") @RequestPart() MultipartFile file,
                                         @ApiParam("目标桶名称") @RequestParam(required = false) String bucket,
                                         @ApiParam("业务标识") @RequestParam(required = false) String busCode) {
        // 文件上传
        return ResultWrapper.success(minIoTemplate.putObject(file, bucket, file.getOriginalFilename(), true, busCode));
    }

    @PostMapping("channelUpload")
    @ApiOperation("上传文件")
    public ResultWrapper<OssFile> channelUpload(@ApiParam("上传的文件") @RequestPart() MultipartFile file,
                                                @ApiParam("appId") @RequestParam(required = false) String appId,
                                         @ApiParam("accessKey") @RequestParam(required = false) String accessKey) {
        // 文件上传
        return ResultWrapper.success(minIoTemplate.putObject(file, appId, accessKey, file.getOriginalFilename(), true));
    }
    @PostMapping("uploadUndoubled")
    @ApiOperation("上传文件。相同文件名是直接覆盖")
    public ResultWrapper<OssFile> uploadUndoubled(@ApiParam("上传的文件") @RequestPart() MultipartFile file,
                                         @ApiParam("目标桶名称") @RequestParam(required = false) String bucket,
                                                  @ApiParam("业务标识") @RequestParam(required = false) String busCode) {
        // 文件上传
        return ResultWrapper.success(minIoTemplate.putObject(file, bucket, file.getOriginalFilename(), false, busCode));
    }

    @PostMapping("getDownloadUrl")
    @ApiOperation("获取下载地址")
    public ResultWrapper<FileUrlVo> getDownloadUrl(@ApiParam("目标桶名称") @RequestParam String bucket,
                                                   @ApiParam("目标文件路径") @RequestParam String ossFilePath) {
        // 获取文件url
        return ResultWrapper.success(minIoTemplate.getPresignedObjectUrl(bucket, ossFilePath));
    }

    @PostMapping("channelDownloadUrl")
    @ApiOperation("获取下载地址")
    public void channelDownloadUrl(@ApiParam("appId") @RequestParam String appId,
                                                       @ApiParam("accessKey") @RequestParam String accessKey,
                                                   HttpServletResponse response,
                                                   @ApiParam("目标文件路径") @RequestParam String ossFilePath) {
        // 获取文件url
        minIoTemplate.getPresignedObjectUrl(appId, accessKey, ossFilePath, response);
    }
}