package com.taiji.system.util;

import com.taiji.system.enums.ResultStatusEnum;
import io.swagger.annotations.ApiModelProperty;

import java.io.Serializable;

/***
 * <p>
 * 接口、异常返回格式封装类
 * </p>
 * @author hou yi
 * @date 2022/7/27 11:13
 **/
public class ResultWrapper<T> implements Serializable {

    @ApiModelProperty("状态码")
    private Integer code;

    @ApiModelProperty("提示语")
    private String msg;

    /*** 返回数据 */
    private T data;

    public ResultWrapper() {
    }

    public ResultWrapper(Integer code, String msg, T data) {
        this.code = code;
        this.msg = msg;
        this.data = data;
    }

    /***
     * 请求成功。有返回数据值
     * @return 、
     */
    public static <T> ResultWrapper<T> success(T t) {
        return new ResultWrapper<T>(ResultStatusEnum.SUCCESS.getCode(), ResultStatusEnum.SUCCESS.getMessage(), t);
    }

    /***
     * 请求成功。无返回数据值
     * @return 、
     */
    public static <T> ResultWrapper<T> success() {
        return new ResultWrapper<T>(ResultStatusEnum.SUCCESS.getCode(), ResultStatusEnum.SUCCESS.getMessage(), null);
    }

    /***
     * 请求失败。有返回数据值
     * @return 、
     */
    public static <T> ResultWrapper<T> fail(T t) {
        return new ResultWrapper<T>(ResultStatusEnum.FAIL.getCode(), ResultStatusEnum.FAIL.getMessage(), t);
    }

    /***
     * 请求失败。
     * @return 、
     */
    public static <T> ResultWrapper<T> fail(int code, String msg) {
        return new ResultWrapper<T>(code, msg, null);
    }

    /***
     * 请求失败。无返回数据值
     * @return 、
     */
    public static <T> ResultWrapper<T> fail() {
        return new ResultWrapper<T>(ResultStatusEnum.FAIL.getCode(), ResultStatusEnum.FAIL.getMessage(), null);
    }

    public Integer getCode() {
        return code;
    }

    public void setCode(Integer code) {
        this.code = code;
    }

    public String getMsg() {
        return msg;
    }

    public void setMsg(String msg) {
        this.msg = msg;
    }

    public T getData() {
        return data;
    }

    public void setData(T data) {
        this.data = data;
    }
}
